/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/m-192-lnx64-xr/build/dom/interfaces/css/nsIDOMNSCSS2Properties.idl
 */

#ifndef __gen_nsIDOMNSCSS2Properties_h__
#define __gen_nsIDOMNSCSS2Properties_h__


#ifndef __gen_nsIDOMCSS2Properties_h__
#include "nsIDOMCSS2Properties.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMNSCSS2Properties */
#define NS_IDOMNSCSS2PROPERTIES_IID_STR "8c31e4a6-8f3a-4bb9-b180-8385ac2a4080"

#define NS_IDOMNSCSS2PROPERTIES_IID \
  {0x8c31e4a6, 0x8f3a, 0x4bb9, \
    { 0xb1, 0x80, 0x83, 0x85, 0xac, 0x2a, 0x40, 0x80 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIDOMNSCSS2Properties : public nsIDOMCSS2Properties {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMNSCSS2PROPERTIES_IID)

  /* attribute DOMString MozAppearance; */
  NS_SCRIPTABLE NS_IMETHOD GetMozAppearance(nsAString & aMozAppearance) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozAppearance(const nsAString & aMozAppearance) = 0;

  /* attribute DOMString MozBackgroundClip; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundClip(nsAString & aMozBackgroundClip) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundClip(const nsAString & aMozBackgroundClip) = 0;

  /* attribute DOMString MozBackgroundInlinePolicy; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundInlinePolicy(nsAString & aMozBackgroundInlinePolicy) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundInlinePolicy(const nsAString & aMozBackgroundInlinePolicy) = 0;

  /* attribute DOMString MozBackgroundOrigin; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundOrigin(nsAString & aMozBackgroundOrigin) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundOrigin(const nsAString & aMozBackgroundOrigin) = 0;

  /* attribute DOMString MozBinding; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBinding(nsAString & aMozBinding) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBinding(const nsAString & aMozBinding) = 0;

  /* attribute DOMString MozBorderBottomColors; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderBottomColors(nsAString & aMozBorderBottomColors) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderBottomColors(const nsAString & aMozBorderBottomColors) = 0;

  /* attribute DOMString MozBorderLeftColors; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderLeftColors(nsAString & aMozBorderLeftColors) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderLeftColors(const nsAString & aMozBorderLeftColors) = 0;

  /* attribute DOMString MozBorderRightColors; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRightColors(nsAString & aMozBorderRightColors) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRightColors(const nsAString & aMozBorderRightColors) = 0;

  /* attribute DOMString MozBorderTopColors; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderTopColors(nsAString & aMozBorderTopColors) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderTopColors(const nsAString & aMozBorderTopColors) = 0;

  /* attribute DOMString MozBorderRadius; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadius(nsAString & aMozBorderRadius) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadius(const nsAString & aMozBorderRadius) = 0;

  /* attribute DOMString MozBorderRadiusTopleft; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopleft(nsAString & aMozBorderRadiusTopleft) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopleft(const nsAString & aMozBorderRadiusTopleft) = 0;

  /* attribute DOMString MozBorderRadiusTopright; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopright(nsAString & aMozBorderRadiusTopright) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopright(const nsAString & aMozBorderRadiusTopright) = 0;

  /* attribute DOMString MozBorderRadiusBottomleft; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomleft(nsAString & aMozBorderRadiusBottomleft) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomleft(const nsAString & aMozBorderRadiusBottomleft) = 0;

  /* attribute DOMString MozBorderRadiusBottomright; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomright(nsAString & aMozBorderRadiusBottomright) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomright(const nsAString & aMozBorderRadiusBottomright) = 0;

  /* attribute DOMString MozBoxAlign; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxAlign(nsAString & aMozBoxAlign) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxAlign(const nsAString & aMozBoxAlign) = 0;

  /* attribute DOMString MozBoxDirection; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxDirection(nsAString & aMozBoxDirection) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxDirection(const nsAString & aMozBoxDirection) = 0;

  /* attribute DOMString MozBoxFlex; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxFlex(nsAString & aMozBoxFlex) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxFlex(const nsAString & aMozBoxFlex) = 0;

  /* attribute DOMString MozBoxOrient; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrient(nsAString & aMozBoxOrient) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrient(const nsAString & aMozBoxOrient) = 0;

  /* attribute DOMString MozBoxOrdinalGroup; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrdinalGroup(nsAString & aMozBoxOrdinalGroup) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrdinalGroup(const nsAString & aMozBoxOrdinalGroup) = 0;

  /* attribute DOMString MozBoxPack; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxPack(nsAString & aMozBoxPack) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxPack(const nsAString & aMozBoxPack) = 0;

  /* attribute DOMString MozBoxSizing; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxSizing(nsAString & aMozBoxSizing) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxSizing(const nsAString & aMozBoxSizing) = 0;

  /* attribute DOMString MozColumnCount; */
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnCount(nsAString & aMozColumnCount) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnCount(const nsAString & aMozColumnCount) = 0;

  /* attribute DOMString MozColumnWidth; */
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnWidth(nsAString & aMozColumnWidth) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnWidth(const nsAString & aMozColumnWidth) = 0;

  /* attribute DOMString MozColumnGap; */
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnGap(nsAString & aMozColumnGap) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnGap(const nsAString & aMozColumnGap) = 0;

  /* attribute DOMString MozFloatEdge; */
  NS_SCRIPTABLE NS_IMETHOD GetMozFloatEdge(nsAString & aMozFloatEdge) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozFloatEdge(const nsAString & aMozFloatEdge) = 0;

  /* attribute DOMString MozForceBrokenImageIcon; */
  NS_SCRIPTABLE NS_IMETHOD GetMozForceBrokenImageIcon(nsAString & aMozForceBrokenImageIcon) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozForceBrokenImageIcon(const nsAString & aMozForceBrokenImageIcon) = 0;

  /* attribute DOMString MozImageRegion; */
  NS_SCRIPTABLE NS_IMETHOD GetMozImageRegion(nsAString & aMozImageRegion) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozImageRegion(const nsAString & aMozImageRegion) = 0;

  /* attribute DOMString MozMarginEnd; */
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginEnd(nsAString & aMozMarginEnd) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginEnd(const nsAString & aMozMarginEnd) = 0;

  /* attribute DOMString MozMarginStart; */
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginStart(nsAString & aMozMarginStart) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginStart(const nsAString & aMozMarginStart) = 0;

  /* attribute DOMString MozOpacity; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOpacity(nsAString & aMozOpacity) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOpacity(const nsAString & aMozOpacity) = 0;

  /* attribute DOMString MozOutline; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutline(nsAString & aMozOutline) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutline(const nsAString & aMozOutline) = 0;

  /* attribute DOMString MozOutlineColor; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineColor(nsAString & aMozOutlineColor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineColor(const nsAString & aMozOutlineColor) = 0;

  /* attribute DOMString MozOutlineRadius; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadius(nsAString & aMozOutlineRadius) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadius(const nsAString & aMozOutlineRadius) = 0;

  /* attribute DOMString MozOutlineRadiusTopleft; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopleft(nsAString & aMozOutlineRadiusTopleft) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopleft(const nsAString & aMozOutlineRadiusTopleft) = 0;

  /* attribute DOMString MozOutlineRadiusTopright; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopright(nsAString & aMozOutlineRadiusTopright) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopright(const nsAString & aMozOutlineRadiusTopright) = 0;

  /* attribute DOMString MozOutlineRadiusBottomleft; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomleft(nsAString & aMozOutlineRadiusBottomleft) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomleft(const nsAString & aMozOutlineRadiusBottomleft) = 0;

  /* attribute DOMString MozOutlineRadiusBottomright; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomright(nsAString & aMozOutlineRadiusBottomright) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomright(const nsAString & aMozOutlineRadiusBottomright) = 0;

  /* attribute DOMString MozOutlineStyle; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineStyle(nsAString & aMozOutlineStyle) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineStyle(const nsAString & aMozOutlineStyle) = 0;

  /* attribute DOMString MozOutlineWidth; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineWidth(nsAString & aMozOutlineWidth) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineWidth(const nsAString & aMozOutlineWidth) = 0;

  /* attribute DOMString MozOutlineOffset; */
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineOffset(nsAString & aMozOutlineOffset) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineOffset(const nsAString & aMozOutlineOffset) = 0;

  /* attribute DOMString MozPaddingEnd; */
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingEnd(nsAString & aMozPaddingEnd) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingEnd(const nsAString & aMozPaddingEnd) = 0;

  /* attribute DOMString MozPaddingStart; */
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingStart(nsAString & aMozPaddingStart) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingStart(const nsAString & aMozPaddingStart) = 0;

  /* attribute DOMString MozUserFocus; */
  NS_SCRIPTABLE NS_IMETHOD GetMozUserFocus(nsAString & aMozUserFocus) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozUserFocus(const nsAString & aMozUserFocus) = 0;

  /* attribute DOMString MozUserInput; */
  NS_SCRIPTABLE NS_IMETHOD GetMozUserInput(nsAString & aMozUserInput) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozUserInput(const nsAString & aMozUserInput) = 0;

  /* attribute DOMString MozUserModify; */
  NS_SCRIPTABLE NS_IMETHOD GetMozUserModify(nsAString & aMozUserModify) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozUserModify(const nsAString & aMozUserModify) = 0;

  /* attribute DOMString MozUserSelect; */
  NS_SCRIPTABLE NS_IMETHOD GetMozUserSelect(nsAString & aMozUserSelect) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozUserSelect(const nsAString & aMozUserSelect) = 0;

  /* attribute DOMString opacity; */
  NS_SCRIPTABLE NS_IMETHOD GetOpacity(nsAString & aOpacity) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetOpacity(const nsAString & aOpacity) = 0;

  /* attribute DOMString outlineOffset; */
  NS_SCRIPTABLE NS_IMETHOD GetOutlineOffset(nsAString & aOutlineOffset) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetOutlineOffset(const nsAString & aOutlineOffset) = 0;

  /* attribute DOMString overflowX; */
  NS_SCRIPTABLE NS_IMETHOD GetOverflowX(nsAString & aOverflowX) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetOverflowX(const nsAString & aOverflowX) = 0;

  /* attribute DOMString overflowY; */
  NS_SCRIPTABLE NS_IMETHOD GetOverflowY(nsAString & aOverflowY) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetOverflowY(const nsAString & aOverflowY) = 0;

  /* attribute DOMString imeMode; */
  NS_SCRIPTABLE NS_IMETHOD GetImeMode(nsAString & aImeMode) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetImeMode(const nsAString & aImeMode) = 0;

  /* attribute DOMString MozBorderEnd; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEnd(nsAString & aMozBorderEnd) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEnd(const nsAString & aMozBorderEnd) = 0;

  /* attribute DOMString MozBorderEndColor; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndColor(nsAString & aMozBorderEndColor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndColor(const nsAString & aMozBorderEndColor) = 0;

  /* attribute DOMString MozBorderEndStyle; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndStyle(nsAString & aMozBorderEndStyle) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndStyle(const nsAString & aMozBorderEndStyle) = 0;

  /* attribute DOMString MozBorderEndWidth; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndWidth(nsAString & aMozBorderEndWidth) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndWidth(const nsAString & aMozBorderEndWidth) = 0;

  /* attribute DOMString MozBorderStart; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStart(nsAString & aMozBorderStart) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStart(const nsAString & aMozBorderStart) = 0;

  /* attribute DOMString MozBorderStartColor; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartColor(nsAString & aMozBorderStartColor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartColor(const nsAString & aMozBorderStartColor) = 0;

  /* attribute DOMString MozBorderStartStyle; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartStyle(nsAString & aMozBorderStartStyle) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartStyle(const nsAString & aMozBorderStartStyle) = 0;

  /* attribute DOMString MozBorderStartWidth; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartWidth(nsAString & aMozBorderStartWidth) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartWidth(const nsAString & aMozBorderStartWidth) = 0;

  /* attribute DOMString MozStackSizing; */
  NS_SCRIPTABLE NS_IMETHOD GetMozStackSizing(nsAString & aMozStackSizing) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozStackSizing(const nsAString & aMozStackSizing) = 0;

  /* attribute DOMString MozBoxShadow; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxShadow(nsAString & aMozBoxShadow) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxShadow(const nsAString & aMozBoxShadow) = 0;

  /* attribute DOMString MozBorderImage; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderImage(nsAString & aMozBorderImage) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderImage(const nsAString & aMozBorderImage) = 0;

  /* attribute DOMString MozColumnRule; */
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRule(nsAString & aMozColumnRule) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRule(const nsAString & aMozColumnRule) = 0;

  /* attribute DOMString MozColumnRuleWidth; */
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleWidth(nsAString & aMozColumnRuleWidth) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleWidth(const nsAString & aMozColumnRuleWidth) = 0;

  /* attribute DOMString MozColumnRuleStyle; */
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleStyle(nsAString & aMozColumnRuleStyle) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleStyle(const nsAString & aMozColumnRuleStyle) = 0;

  /* attribute DOMString MozColumnRuleColor; */
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleColor(nsAString & aMozColumnRuleColor) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleColor(const nsAString & aMozColumnRuleColor) = 0;

  /* attribute DOMString wordWrap; */
  NS_SCRIPTABLE NS_IMETHOD GetWordWrap(nsAString & aWordWrap) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetWordWrap(const nsAString & aWordWrap) = 0;

  /* attribute DOMString MozTransform; */
  NS_SCRIPTABLE NS_IMETHOD GetMozTransform(nsAString & aMozTransform) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozTransform(const nsAString & aMozTransform) = 0;

  /* attribute DOMString MozTransformOrigin; */
  NS_SCRIPTABLE NS_IMETHOD GetMozTransformOrigin(nsAString & aMozTransformOrigin) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozTransformOrigin(const nsAString & aMozTransformOrigin) = 0;

  /* attribute DOMString MozWindowShadow; */
  NS_SCRIPTABLE NS_IMETHOD GetMozWindowShadow(nsAString & aMozWindowShadow) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozWindowShadow(const nsAString & aMozWindowShadow) = 0;

  /* attribute DOMString MozBackgroundSize; */
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundSize(nsAString & aMozBackgroundSize) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundSize(const nsAString & aMozBackgroundSize) = 0;

  /* attribute DOMString pointerEvents; */
  NS_SCRIPTABLE NS_IMETHOD GetPointerEvents(nsAString & aPointerEvents) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetPointerEvents(const nsAString & aPointerEvents) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMNSCSS2Properties, NS_IDOMNSCSS2PROPERTIES_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMNSCSS2PROPERTIES \
  NS_SCRIPTABLE NS_IMETHOD GetMozAppearance(nsAString & aMozAppearance); \
  NS_SCRIPTABLE NS_IMETHOD SetMozAppearance(const nsAString & aMozAppearance); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundClip(nsAString & aMozBackgroundClip); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundClip(const nsAString & aMozBackgroundClip); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundInlinePolicy(nsAString & aMozBackgroundInlinePolicy); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundInlinePolicy(const nsAString & aMozBackgroundInlinePolicy); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundOrigin(nsAString & aMozBackgroundOrigin); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundOrigin(const nsAString & aMozBackgroundOrigin); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBinding(nsAString & aMozBinding); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBinding(const nsAString & aMozBinding); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderBottomColors(nsAString & aMozBorderBottomColors); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderBottomColors(const nsAString & aMozBorderBottomColors); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderLeftColors(nsAString & aMozBorderLeftColors); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderLeftColors(const nsAString & aMozBorderLeftColors); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRightColors(nsAString & aMozBorderRightColors); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRightColors(const nsAString & aMozBorderRightColors); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderTopColors(nsAString & aMozBorderTopColors); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderTopColors(const nsAString & aMozBorderTopColors); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadius(nsAString & aMozBorderRadius); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadius(const nsAString & aMozBorderRadius); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopleft(nsAString & aMozBorderRadiusTopleft); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopleft(const nsAString & aMozBorderRadiusTopleft); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopright(nsAString & aMozBorderRadiusTopright); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopright(const nsAString & aMozBorderRadiusTopright); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomleft(nsAString & aMozBorderRadiusBottomleft); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomleft(const nsAString & aMozBorderRadiusBottomleft); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomright(nsAString & aMozBorderRadiusBottomright); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomright(const nsAString & aMozBorderRadiusBottomright); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxAlign(nsAString & aMozBoxAlign); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxAlign(const nsAString & aMozBoxAlign); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxDirection(nsAString & aMozBoxDirection); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxDirection(const nsAString & aMozBoxDirection); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxFlex(nsAString & aMozBoxFlex); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxFlex(const nsAString & aMozBoxFlex); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrient(nsAString & aMozBoxOrient); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrient(const nsAString & aMozBoxOrient); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrdinalGroup(nsAString & aMozBoxOrdinalGroup); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrdinalGroup(const nsAString & aMozBoxOrdinalGroup); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxPack(nsAString & aMozBoxPack); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxPack(const nsAString & aMozBoxPack); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxSizing(nsAString & aMozBoxSizing); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxSizing(const nsAString & aMozBoxSizing); \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnCount(nsAString & aMozColumnCount); \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnCount(const nsAString & aMozColumnCount); \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnWidth(nsAString & aMozColumnWidth); \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnWidth(const nsAString & aMozColumnWidth); \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnGap(nsAString & aMozColumnGap); \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnGap(const nsAString & aMozColumnGap); \
  NS_SCRIPTABLE NS_IMETHOD GetMozFloatEdge(nsAString & aMozFloatEdge); \
  NS_SCRIPTABLE NS_IMETHOD SetMozFloatEdge(const nsAString & aMozFloatEdge); \
  NS_SCRIPTABLE NS_IMETHOD GetMozForceBrokenImageIcon(nsAString & aMozForceBrokenImageIcon); \
  NS_SCRIPTABLE NS_IMETHOD SetMozForceBrokenImageIcon(const nsAString & aMozForceBrokenImageIcon); \
  NS_SCRIPTABLE NS_IMETHOD GetMozImageRegion(nsAString & aMozImageRegion); \
  NS_SCRIPTABLE NS_IMETHOD SetMozImageRegion(const nsAString & aMozImageRegion); \
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginEnd(nsAString & aMozMarginEnd); \
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginEnd(const nsAString & aMozMarginEnd); \
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginStart(nsAString & aMozMarginStart); \
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginStart(const nsAString & aMozMarginStart); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOpacity(nsAString & aMozOpacity); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOpacity(const nsAString & aMozOpacity); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutline(nsAString & aMozOutline); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutline(const nsAString & aMozOutline); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineColor(nsAString & aMozOutlineColor); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineColor(const nsAString & aMozOutlineColor); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadius(nsAString & aMozOutlineRadius); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadius(const nsAString & aMozOutlineRadius); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopleft(nsAString & aMozOutlineRadiusTopleft); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopleft(const nsAString & aMozOutlineRadiusTopleft); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopright(nsAString & aMozOutlineRadiusTopright); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopright(const nsAString & aMozOutlineRadiusTopright); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomleft(nsAString & aMozOutlineRadiusBottomleft); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomleft(const nsAString & aMozOutlineRadiusBottomleft); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomright(nsAString & aMozOutlineRadiusBottomright); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomright(const nsAString & aMozOutlineRadiusBottomright); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineStyle(nsAString & aMozOutlineStyle); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineStyle(const nsAString & aMozOutlineStyle); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineWidth(nsAString & aMozOutlineWidth); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineWidth(const nsAString & aMozOutlineWidth); \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineOffset(nsAString & aMozOutlineOffset); \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineOffset(const nsAString & aMozOutlineOffset); \
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingEnd(nsAString & aMozPaddingEnd); \
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingEnd(const nsAString & aMozPaddingEnd); \
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingStart(nsAString & aMozPaddingStart); \
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingStart(const nsAString & aMozPaddingStart); \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserFocus(nsAString & aMozUserFocus); \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserFocus(const nsAString & aMozUserFocus); \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserInput(nsAString & aMozUserInput); \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserInput(const nsAString & aMozUserInput); \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserModify(nsAString & aMozUserModify); \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserModify(const nsAString & aMozUserModify); \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserSelect(nsAString & aMozUserSelect); \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserSelect(const nsAString & aMozUserSelect); \
  NS_SCRIPTABLE NS_IMETHOD GetOpacity(nsAString & aOpacity); \
  NS_SCRIPTABLE NS_IMETHOD SetOpacity(const nsAString & aOpacity); \
  NS_SCRIPTABLE NS_IMETHOD GetOutlineOffset(nsAString & aOutlineOffset); \
  NS_SCRIPTABLE NS_IMETHOD SetOutlineOffset(const nsAString & aOutlineOffset); \
  NS_SCRIPTABLE NS_IMETHOD GetOverflowX(nsAString & aOverflowX); \
  NS_SCRIPTABLE NS_IMETHOD SetOverflowX(const nsAString & aOverflowX); \
  NS_SCRIPTABLE NS_IMETHOD GetOverflowY(nsAString & aOverflowY); \
  NS_SCRIPTABLE NS_IMETHOD SetOverflowY(const nsAString & aOverflowY); \
  NS_SCRIPTABLE NS_IMETHOD GetImeMode(nsAString & aImeMode); \
  NS_SCRIPTABLE NS_IMETHOD SetImeMode(const nsAString & aImeMode); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEnd(nsAString & aMozBorderEnd); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEnd(const nsAString & aMozBorderEnd); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndColor(nsAString & aMozBorderEndColor); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndColor(const nsAString & aMozBorderEndColor); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndStyle(nsAString & aMozBorderEndStyle); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndStyle(const nsAString & aMozBorderEndStyle); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndWidth(nsAString & aMozBorderEndWidth); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndWidth(const nsAString & aMozBorderEndWidth); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStart(nsAString & aMozBorderStart); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStart(const nsAString & aMozBorderStart); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartColor(nsAString & aMozBorderStartColor); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartColor(const nsAString & aMozBorderStartColor); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartStyle(nsAString & aMozBorderStartStyle); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartStyle(const nsAString & aMozBorderStartStyle); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartWidth(nsAString & aMozBorderStartWidth); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartWidth(const nsAString & aMozBorderStartWidth); \
  NS_SCRIPTABLE NS_IMETHOD GetMozStackSizing(nsAString & aMozStackSizing); \
  NS_SCRIPTABLE NS_IMETHOD SetMozStackSizing(const nsAString & aMozStackSizing); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxShadow(nsAString & aMozBoxShadow); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxShadow(const nsAString & aMozBoxShadow); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderImage(nsAString & aMozBorderImage); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderImage(const nsAString & aMozBorderImage); \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRule(nsAString & aMozColumnRule); \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRule(const nsAString & aMozColumnRule); \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleWidth(nsAString & aMozColumnRuleWidth); \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleWidth(const nsAString & aMozColumnRuleWidth); \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleStyle(nsAString & aMozColumnRuleStyle); \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleStyle(const nsAString & aMozColumnRuleStyle); \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleColor(nsAString & aMozColumnRuleColor); \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleColor(const nsAString & aMozColumnRuleColor); \
  NS_SCRIPTABLE NS_IMETHOD GetWordWrap(nsAString & aWordWrap); \
  NS_SCRIPTABLE NS_IMETHOD SetWordWrap(const nsAString & aWordWrap); \
  NS_SCRIPTABLE NS_IMETHOD GetMozTransform(nsAString & aMozTransform); \
  NS_SCRIPTABLE NS_IMETHOD SetMozTransform(const nsAString & aMozTransform); \
  NS_SCRIPTABLE NS_IMETHOD GetMozTransformOrigin(nsAString & aMozTransformOrigin); \
  NS_SCRIPTABLE NS_IMETHOD SetMozTransformOrigin(const nsAString & aMozTransformOrigin); \
  NS_SCRIPTABLE NS_IMETHOD GetMozWindowShadow(nsAString & aMozWindowShadow); \
  NS_SCRIPTABLE NS_IMETHOD SetMozWindowShadow(const nsAString & aMozWindowShadow); \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundSize(nsAString & aMozBackgroundSize); \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundSize(const nsAString & aMozBackgroundSize); \
  NS_SCRIPTABLE NS_IMETHOD GetPointerEvents(nsAString & aPointerEvents); \
  NS_SCRIPTABLE NS_IMETHOD SetPointerEvents(const nsAString & aPointerEvents); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMNSCSS2PROPERTIES(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetMozAppearance(nsAString & aMozAppearance) { return _to GetMozAppearance(aMozAppearance); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozAppearance(const nsAString & aMozAppearance) { return _to SetMozAppearance(aMozAppearance); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundClip(nsAString & aMozBackgroundClip) { return _to GetMozBackgroundClip(aMozBackgroundClip); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundClip(const nsAString & aMozBackgroundClip) { return _to SetMozBackgroundClip(aMozBackgroundClip); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundInlinePolicy(nsAString & aMozBackgroundInlinePolicy) { return _to GetMozBackgroundInlinePolicy(aMozBackgroundInlinePolicy); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundInlinePolicy(const nsAString & aMozBackgroundInlinePolicy) { return _to SetMozBackgroundInlinePolicy(aMozBackgroundInlinePolicy); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundOrigin(nsAString & aMozBackgroundOrigin) { return _to GetMozBackgroundOrigin(aMozBackgroundOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundOrigin(const nsAString & aMozBackgroundOrigin) { return _to SetMozBackgroundOrigin(aMozBackgroundOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBinding(nsAString & aMozBinding) { return _to GetMozBinding(aMozBinding); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBinding(const nsAString & aMozBinding) { return _to SetMozBinding(aMozBinding); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderBottomColors(nsAString & aMozBorderBottomColors) { return _to GetMozBorderBottomColors(aMozBorderBottomColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderBottomColors(const nsAString & aMozBorderBottomColors) { return _to SetMozBorderBottomColors(aMozBorderBottomColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderLeftColors(nsAString & aMozBorderLeftColors) { return _to GetMozBorderLeftColors(aMozBorderLeftColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderLeftColors(const nsAString & aMozBorderLeftColors) { return _to SetMozBorderLeftColors(aMozBorderLeftColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRightColors(nsAString & aMozBorderRightColors) { return _to GetMozBorderRightColors(aMozBorderRightColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRightColors(const nsAString & aMozBorderRightColors) { return _to SetMozBorderRightColors(aMozBorderRightColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderTopColors(nsAString & aMozBorderTopColors) { return _to GetMozBorderTopColors(aMozBorderTopColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderTopColors(const nsAString & aMozBorderTopColors) { return _to SetMozBorderTopColors(aMozBorderTopColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadius(nsAString & aMozBorderRadius) { return _to GetMozBorderRadius(aMozBorderRadius); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadius(const nsAString & aMozBorderRadius) { return _to SetMozBorderRadius(aMozBorderRadius); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopleft(nsAString & aMozBorderRadiusTopleft) { return _to GetMozBorderRadiusTopleft(aMozBorderRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopleft(const nsAString & aMozBorderRadiusTopleft) { return _to SetMozBorderRadiusTopleft(aMozBorderRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopright(nsAString & aMozBorderRadiusTopright) { return _to GetMozBorderRadiusTopright(aMozBorderRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopright(const nsAString & aMozBorderRadiusTopright) { return _to SetMozBorderRadiusTopright(aMozBorderRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomleft(nsAString & aMozBorderRadiusBottomleft) { return _to GetMozBorderRadiusBottomleft(aMozBorderRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomleft(const nsAString & aMozBorderRadiusBottomleft) { return _to SetMozBorderRadiusBottomleft(aMozBorderRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomright(nsAString & aMozBorderRadiusBottomright) { return _to GetMozBorderRadiusBottomright(aMozBorderRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomright(const nsAString & aMozBorderRadiusBottomright) { return _to SetMozBorderRadiusBottomright(aMozBorderRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxAlign(nsAString & aMozBoxAlign) { return _to GetMozBoxAlign(aMozBoxAlign); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxAlign(const nsAString & aMozBoxAlign) { return _to SetMozBoxAlign(aMozBoxAlign); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxDirection(nsAString & aMozBoxDirection) { return _to GetMozBoxDirection(aMozBoxDirection); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxDirection(const nsAString & aMozBoxDirection) { return _to SetMozBoxDirection(aMozBoxDirection); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxFlex(nsAString & aMozBoxFlex) { return _to GetMozBoxFlex(aMozBoxFlex); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxFlex(const nsAString & aMozBoxFlex) { return _to SetMozBoxFlex(aMozBoxFlex); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrient(nsAString & aMozBoxOrient) { return _to GetMozBoxOrient(aMozBoxOrient); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrient(const nsAString & aMozBoxOrient) { return _to SetMozBoxOrient(aMozBoxOrient); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrdinalGroup(nsAString & aMozBoxOrdinalGroup) { return _to GetMozBoxOrdinalGroup(aMozBoxOrdinalGroup); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrdinalGroup(const nsAString & aMozBoxOrdinalGroup) { return _to SetMozBoxOrdinalGroup(aMozBoxOrdinalGroup); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxPack(nsAString & aMozBoxPack) { return _to GetMozBoxPack(aMozBoxPack); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxPack(const nsAString & aMozBoxPack) { return _to SetMozBoxPack(aMozBoxPack); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxSizing(nsAString & aMozBoxSizing) { return _to GetMozBoxSizing(aMozBoxSizing); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxSizing(const nsAString & aMozBoxSizing) { return _to SetMozBoxSizing(aMozBoxSizing); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnCount(nsAString & aMozColumnCount) { return _to GetMozColumnCount(aMozColumnCount); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnCount(const nsAString & aMozColumnCount) { return _to SetMozColumnCount(aMozColumnCount); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnWidth(nsAString & aMozColumnWidth) { return _to GetMozColumnWidth(aMozColumnWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnWidth(const nsAString & aMozColumnWidth) { return _to SetMozColumnWidth(aMozColumnWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnGap(nsAString & aMozColumnGap) { return _to GetMozColumnGap(aMozColumnGap); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnGap(const nsAString & aMozColumnGap) { return _to SetMozColumnGap(aMozColumnGap); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozFloatEdge(nsAString & aMozFloatEdge) { return _to GetMozFloatEdge(aMozFloatEdge); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozFloatEdge(const nsAString & aMozFloatEdge) { return _to SetMozFloatEdge(aMozFloatEdge); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozForceBrokenImageIcon(nsAString & aMozForceBrokenImageIcon) { return _to GetMozForceBrokenImageIcon(aMozForceBrokenImageIcon); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozForceBrokenImageIcon(const nsAString & aMozForceBrokenImageIcon) { return _to SetMozForceBrokenImageIcon(aMozForceBrokenImageIcon); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozImageRegion(nsAString & aMozImageRegion) { return _to GetMozImageRegion(aMozImageRegion); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozImageRegion(const nsAString & aMozImageRegion) { return _to SetMozImageRegion(aMozImageRegion); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginEnd(nsAString & aMozMarginEnd) { return _to GetMozMarginEnd(aMozMarginEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginEnd(const nsAString & aMozMarginEnd) { return _to SetMozMarginEnd(aMozMarginEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginStart(nsAString & aMozMarginStart) { return _to GetMozMarginStart(aMozMarginStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginStart(const nsAString & aMozMarginStart) { return _to SetMozMarginStart(aMozMarginStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOpacity(nsAString & aMozOpacity) { return _to GetMozOpacity(aMozOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOpacity(const nsAString & aMozOpacity) { return _to SetMozOpacity(aMozOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutline(nsAString & aMozOutline) { return _to GetMozOutline(aMozOutline); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutline(const nsAString & aMozOutline) { return _to SetMozOutline(aMozOutline); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineColor(nsAString & aMozOutlineColor) { return _to GetMozOutlineColor(aMozOutlineColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineColor(const nsAString & aMozOutlineColor) { return _to SetMozOutlineColor(aMozOutlineColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadius(nsAString & aMozOutlineRadius) { return _to GetMozOutlineRadius(aMozOutlineRadius); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadius(const nsAString & aMozOutlineRadius) { return _to SetMozOutlineRadius(aMozOutlineRadius); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopleft(nsAString & aMozOutlineRadiusTopleft) { return _to GetMozOutlineRadiusTopleft(aMozOutlineRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopleft(const nsAString & aMozOutlineRadiusTopleft) { return _to SetMozOutlineRadiusTopleft(aMozOutlineRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopright(nsAString & aMozOutlineRadiusTopright) { return _to GetMozOutlineRadiusTopright(aMozOutlineRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopright(const nsAString & aMozOutlineRadiusTopright) { return _to SetMozOutlineRadiusTopright(aMozOutlineRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomleft(nsAString & aMozOutlineRadiusBottomleft) { return _to GetMozOutlineRadiusBottomleft(aMozOutlineRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomleft(const nsAString & aMozOutlineRadiusBottomleft) { return _to SetMozOutlineRadiusBottomleft(aMozOutlineRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomright(nsAString & aMozOutlineRadiusBottomright) { return _to GetMozOutlineRadiusBottomright(aMozOutlineRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomright(const nsAString & aMozOutlineRadiusBottomright) { return _to SetMozOutlineRadiusBottomright(aMozOutlineRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineStyle(nsAString & aMozOutlineStyle) { return _to GetMozOutlineStyle(aMozOutlineStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineStyle(const nsAString & aMozOutlineStyle) { return _to SetMozOutlineStyle(aMozOutlineStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineWidth(nsAString & aMozOutlineWidth) { return _to GetMozOutlineWidth(aMozOutlineWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineWidth(const nsAString & aMozOutlineWidth) { return _to SetMozOutlineWidth(aMozOutlineWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineOffset(nsAString & aMozOutlineOffset) { return _to GetMozOutlineOffset(aMozOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineOffset(const nsAString & aMozOutlineOffset) { return _to SetMozOutlineOffset(aMozOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingEnd(nsAString & aMozPaddingEnd) { return _to GetMozPaddingEnd(aMozPaddingEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingEnd(const nsAString & aMozPaddingEnd) { return _to SetMozPaddingEnd(aMozPaddingEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingStart(nsAString & aMozPaddingStart) { return _to GetMozPaddingStart(aMozPaddingStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingStart(const nsAString & aMozPaddingStart) { return _to SetMozPaddingStart(aMozPaddingStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserFocus(nsAString & aMozUserFocus) { return _to GetMozUserFocus(aMozUserFocus); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserFocus(const nsAString & aMozUserFocus) { return _to SetMozUserFocus(aMozUserFocus); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserInput(nsAString & aMozUserInput) { return _to GetMozUserInput(aMozUserInput); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserInput(const nsAString & aMozUserInput) { return _to SetMozUserInput(aMozUserInput); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserModify(nsAString & aMozUserModify) { return _to GetMozUserModify(aMozUserModify); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserModify(const nsAString & aMozUserModify) { return _to SetMozUserModify(aMozUserModify); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserSelect(nsAString & aMozUserSelect) { return _to GetMozUserSelect(aMozUserSelect); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserSelect(const nsAString & aMozUserSelect) { return _to SetMozUserSelect(aMozUserSelect); } \
  NS_SCRIPTABLE NS_IMETHOD GetOpacity(nsAString & aOpacity) { return _to GetOpacity(aOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetOpacity(const nsAString & aOpacity) { return _to SetOpacity(aOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetOutlineOffset(nsAString & aOutlineOffset) { return _to GetOutlineOffset(aOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD SetOutlineOffset(const nsAString & aOutlineOffset) { return _to SetOutlineOffset(aOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD GetOverflowX(nsAString & aOverflowX) { return _to GetOverflowX(aOverflowX); } \
  NS_SCRIPTABLE NS_IMETHOD SetOverflowX(const nsAString & aOverflowX) { return _to SetOverflowX(aOverflowX); } \
  NS_SCRIPTABLE NS_IMETHOD GetOverflowY(nsAString & aOverflowY) { return _to GetOverflowY(aOverflowY); } \
  NS_SCRIPTABLE NS_IMETHOD SetOverflowY(const nsAString & aOverflowY) { return _to SetOverflowY(aOverflowY); } \
  NS_SCRIPTABLE NS_IMETHOD GetImeMode(nsAString & aImeMode) { return _to GetImeMode(aImeMode); } \
  NS_SCRIPTABLE NS_IMETHOD SetImeMode(const nsAString & aImeMode) { return _to SetImeMode(aImeMode); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEnd(nsAString & aMozBorderEnd) { return _to GetMozBorderEnd(aMozBorderEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEnd(const nsAString & aMozBorderEnd) { return _to SetMozBorderEnd(aMozBorderEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndColor(nsAString & aMozBorderEndColor) { return _to GetMozBorderEndColor(aMozBorderEndColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndColor(const nsAString & aMozBorderEndColor) { return _to SetMozBorderEndColor(aMozBorderEndColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndStyle(nsAString & aMozBorderEndStyle) { return _to GetMozBorderEndStyle(aMozBorderEndStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndStyle(const nsAString & aMozBorderEndStyle) { return _to SetMozBorderEndStyle(aMozBorderEndStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndWidth(nsAString & aMozBorderEndWidth) { return _to GetMozBorderEndWidth(aMozBorderEndWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndWidth(const nsAString & aMozBorderEndWidth) { return _to SetMozBorderEndWidth(aMozBorderEndWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStart(nsAString & aMozBorderStart) { return _to GetMozBorderStart(aMozBorderStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStart(const nsAString & aMozBorderStart) { return _to SetMozBorderStart(aMozBorderStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartColor(nsAString & aMozBorderStartColor) { return _to GetMozBorderStartColor(aMozBorderStartColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartColor(const nsAString & aMozBorderStartColor) { return _to SetMozBorderStartColor(aMozBorderStartColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartStyle(nsAString & aMozBorderStartStyle) { return _to GetMozBorderStartStyle(aMozBorderStartStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartStyle(const nsAString & aMozBorderStartStyle) { return _to SetMozBorderStartStyle(aMozBorderStartStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartWidth(nsAString & aMozBorderStartWidth) { return _to GetMozBorderStartWidth(aMozBorderStartWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartWidth(const nsAString & aMozBorderStartWidth) { return _to SetMozBorderStartWidth(aMozBorderStartWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozStackSizing(nsAString & aMozStackSizing) { return _to GetMozStackSizing(aMozStackSizing); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozStackSizing(const nsAString & aMozStackSizing) { return _to SetMozStackSizing(aMozStackSizing); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxShadow(nsAString & aMozBoxShadow) { return _to GetMozBoxShadow(aMozBoxShadow); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxShadow(const nsAString & aMozBoxShadow) { return _to SetMozBoxShadow(aMozBoxShadow); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderImage(nsAString & aMozBorderImage) { return _to GetMozBorderImage(aMozBorderImage); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderImage(const nsAString & aMozBorderImage) { return _to SetMozBorderImage(aMozBorderImage); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRule(nsAString & aMozColumnRule) { return _to GetMozColumnRule(aMozColumnRule); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRule(const nsAString & aMozColumnRule) { return _to SetMozColumnRule(aMozColumnRule); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleWidth(nsAString & aMozColumnRuleWidth) { return _to GetMozColumnRuleWidth(aMozColumnRuleWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleWidth(const nsAString & aMozColumnRuleWidth) { return _to SetMozColumnRuleWidth(aMozColumnRuleWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleStyle(nsAString & aMozColumnRuleStyle) { return _to GetMozColumnRuleStyle(aMozColumnRuleStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleStyle(const nsAString & aMozColumnRuleStyle) { return _to SetMozColumnRuleStyle(aMozColumnRuleStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleColor(nsAString & aMozColumnRuleColor) { return _to GetMozColumnRuleColor(aMozColumnRuleColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleColor(const nsAString & aMozColumnRuleColor) { return _to SetMozColumnRuleColor(aMozColumnRuleColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetWordWrap(nsAString & aWordWrap) { return _to GetWordWrap(aWordWrap); } \
  NS_SCRIPTABLE NS_IMETHOD SetWordWrap(const nsAString & aWordWrap) { return _to SetWordWrap(aWordWrap); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozTransform(nsAString & aMozTransform) { return _to GetMozTransform(aMozTransform); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozTransform(const nsAString & aMozTransform) { return _to SetMozTransform(aMozTransform); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozTransformOrigin(nsAString & aMozTransformOrigin) { return _to GetMozTransformOrigin(aMozTransformOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozTransformOrigin(const nsAString & aMozTransformOrigin) { return _to SetMozTransformOrigin(aMozTransformOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozWindowShadow(nsAString & aMozWindowShadow) { return _to GetMozWindowShadow(aMozWindowShadow); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozWindowShadow(const nsAString & aMozWindowShadow) { return _to SetMozWindowShadow(aMozWindowShadow); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundSize(nsAString & aMozBackgroundSize) { return _to GetMozBackgroundSize(aMozBackgroundSize); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundSize(const nsAString & aMozBackgroundSize) { return _to SetMozBackgroundSize(aMozBackgroundSize); } \
  NS_SCRIPTABLE NS_IMETHOD GetPointerEvents(nsAString & aPointerEvents) { return _to GetPointerEvents(aPointerEvents); } \
  NS_SCRIPTABLE NS_IMETHOD SetPointerEvents(const nsAString & aPointerEvents) { return _to SetPointerEvents(aPointerEvents); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMNSCSS2PROPERTIES(_to) \
  NS_SCRIPTABLE NS_IMETHOD GetMozAppearance(nsAString & aMozAppearance) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozAppearance(aMozAppearance); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozAppearance(const nsAString & aMozAppearance) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozAppearance(aMozAppearance); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundClip(nsAString & aMozBackgroundClip) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBackgroundClip(aMozBackgroundClip); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundClip(const nsAString & aMozBackgroundClip) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBackgroundClip(aMozBackgroundClip); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundInlinePolicy(nsAString & aMozBackgroundInlinePolicy) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBackgroundInlinePolicy(aMozBackgroundInlinePolicy); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundInlinePolicy(const nsAString & aMozBackgroundInlinePolicy) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBackgroundInlinePolicy(aMozBackgroundInlinePolicy); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundOrigin(nsAString & aMozBackgroundOrigin) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBackgroundOrigin(aMozBackgroundOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundOrigin(const nsAString & aMozBackgroundOrigin) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBackgroundOrigin(aMozBackgroundOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBinding(nsAString & aMozBinding) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBinding(aMozBinding); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBinding(const nsAString & aMozBinding) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBinding(aMozBinding); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderBottomColors(nsAString & aMozBorderBottomColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderBottomColors(aMozBorderBottomColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderBottomColors(const nsAString & aMozBorderBottomColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderBottomColors(aMozBorderBottomColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderLeftColors(nsAString & aMozBorderLeftColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderLeftColors(aMozBorderLeftColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderLeftColors(const nsAString & aMozBorderLeftColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderLeftColors(aMozBorderLeftColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRightColors(nsAString & aMozBorderRightColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderRightColors(aMozBorderRightColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRightColors(const nsAString & aMozBorderRightColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderRightColors(aMozBorderRightColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderTopColors(nsAString & aMozBorderTopColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderTopColors(aMozBorderTopColors); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderTopColors(const nsAString & aMozBorderTopColors) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderTopColors(aMozBorderTopColors); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadius(nsAString & aMozBorderRadius) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderRadius(aMozBorderRadius); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadius(const nsAString & aMozBorderRadius) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderRadius(aMozBorderRadius); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopleft(nsAString & aMozBorderRadiusTopleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderRadiusTopleft(aMozBorderRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopleft(const nsAString & aMozBorderRadiusTopleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderRadiusTopleft(aMozBorderRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusTopright(nsAString & aMozBorderRadiusTopright) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderRadiusTopright(aMozBorderRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusTopright(const nsAString & aMozBorderRadiusTopright) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderRadiusTopright(aMozBorderRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomleft(nsAString & aMozBorderRadiusBottomleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderRadiusBottomleft(aMozBorderRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomleft(const nsAString & aMozBorderRadiusBottomleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderRadiusBottomleft(aMozBorderRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderRadiusBottomright(nsAString & aMozBorderRadiusBottomright) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderRadiusBottomright(aMozBorderRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderRadiusBottomright(const nsAString & aMozBorderRadiusBottomright) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderRadiusBottomright(aMozBorderRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxAlign(nsAString & aMozBoxAlign) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxAlign(aMozBoxAlign); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxAlign(const nsAString & aMozBoxAlign) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxAlign(aMozBoxAlign); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxDirection(nsAString & aMozBoxDirection) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxDirection(aMozBoxDirection); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxDirection(const nsAString & aMozBoxDirection) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxDirection(aMozBoxDirection); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxFlex(nsAString & aMozBoxFlex) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxFlex(aMozBoxFlex); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxFlex(const nsAString & aMozBoxFlex) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxFlex(aMozBoxFlex); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrient(nsAString & aMozBoxOrient) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxOrient(aMozBoxOrient); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrient(const nsAString & aMozBoxOrient) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxOrient(aMozBoxOrient); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxOrdinalGroup(nsAString & aMozBoxOrdinalGroup) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxOrdinalGroup(aMozBoxOrdinalGroup); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxOrdinalGroup(const nsAString & aMozBoxOrdinalGroup) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxOrdinalGroup(aMozBoxOrdinalGroup); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxPack(nsAString & aMozBoxPack) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxPack(aMozBoxPack); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxPack(const nsAString & aMozBoxPack) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxPack(aMozBoxPack); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxSizing(nsAString & aMozBoxSizing) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxSizing(aMozBoxSizing); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxSizing(const nsAString & aMozBoxSizing) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxSizing(aMozBoxSizing); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnCount(nsAString & aMozColumnCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozColumnCount(aMozColumnCount); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnCount(const nsAString & aMozColumnCount) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozColumnCount(aMozColumnCount); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnWidth(nsAString & aMozColumnWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozColumnWidth(aMozColumnWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnWidth(const nsAString & aMozColumnWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozColumnWidth(aMozColumnWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnGap(nsAString & aMozColumnGap) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozColumnGap(aMozColumnGap); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnGap(const nsAString & aMozColumnGap) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozColumnGap(aMozColumnGap); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozFloatEdge(nsAString & aMozFloatEdge) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozFloatEdge(aMozFloatEdge); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozFloatEdge(const nsAString & aMozFloatEdge) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozFloatEdge(aMozFloatEdge); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozForceBrokenImageIcon(nsAString & aMozForceBrokenImageIcon) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozForceBrokenImageIcon(aMozForceBrokenImageIcon); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozForceBrokenImageIcon(const nsAString & aMozForceBrokenImageIcon) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozForceBrokenImageIcon(aMozForceBrokenImageIcon); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozImageRegion(nsAString & aMozImageRegion) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozImageRegion(aMozImageRegion); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozImageRegion(const nsAString & aMozImageRegion) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozImageRegion(aMozImageRegion); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginEnd(nsAString & aMozMarginEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozMarginEnd(aMozMarginEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginEnd(const nsAString & aMozMarginEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozMarginEnd(aMozMarginEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozMarginStart(nsAString & aMozMarginStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozMarginStart(aMozMarginStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozMarginStart(const nsAString & aMozMarginStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozMarginStart(aMozMarginStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOpacity(nsAString & aMozOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOpacity(aMozOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOpacity(const nsAString & aMozOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOpacity(aMozOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutline(nsAString & aMozOutline) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutline(aMozOutline); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutline(const nsAString & aMozOutline) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutline(aMozOutline); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineColor(nsAString & aMozOutlineColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineColor(aMozOutlineColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineColor(const nsAString & aMozOutlineColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineColor(aMozOutlineColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadius(nsAString & aMozOutlineRadius) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineRadius(aMozOutlineRadius); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadius(const nsAString & aMozOutlineRadius) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineRadius(aMozOutlineRadius); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopleft(nsAString & aMozOutlineRadiusTopleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineRadiusTopleft(aMozOutlineRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopleft(const nsAString & aMozOutlineRadiusTopleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineRadiusTopleft(aMozOutlineRadiusTopleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusTopright(nsAString & aMozOutlineRadiusTopright) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineRadiusTopright(aMozOutlineRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusTopright(const nsAString & aMozOutlineRadiusTopright) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineRadiusTopright(aMozOutlineRadiusTopright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomleft(nsAString & aMozOutlineRadiusBottomleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineRadiusBottomleft(aMozOutlineRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomleft(const nsAString & aMozOutlineRadiusBottomleft) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineRadiusBottomleft(aMozOutlineRadiusBottomleft); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineRadiusBottomright(nsAString & aMozOutlineRadiusBottomright) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineRadiusBottomright(aMozOutlineRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineRadiusBottomright(const nsAString & aMozOutlineRadiusBottomright) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineRadiusBottomright(aMozOutlineRadiusBottomright); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineStyle(nsAString & aMozOutlineStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineStyle(aMozOutlineStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineStyle(const nsAString & aMozOutlineStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineStyle(aMozOutlineStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineWidth(nsAString & aMozOutlineWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineWidth(aMozOutlineWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineWidth(const nsAString & aMozOutlineWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineWidth(aMozOutlineWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozOutlineOffset(nsAString & aMozOutlineOffset) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozOutlineOffset(aMozOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozOutlineOffset(const nsAString & aMozOutlineOffset) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozOutlineOffset(aMozOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingEnd(nsAString & aMozPaddingEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozPaddingEnd(aMozPaddingEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingEnd(const nsAString & aMozPaddingEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozPaddingEnd(aMozPaddingEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozPaddingStart(nsAString & aMozPaddingStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozPaddingStart(aMozPaddingStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozPaddingStart(const nsAString & aMozPaddingStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozPaddingStart(aMozPaddingStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserFocus(nsAString & aMozUserFocus) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozUserFocus(aMozUserFocus); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserFocus(const nsAString & aMozUserFocus) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozUserFocus(aMozUserFocus); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserInput(nsAString & aMozUserInput) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozUserInput(aMozUserInput); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserInput(const nsAString & aMozUserInput) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozUserInput(aMozUserInput); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserModify(nsAString & aMozUserModify) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozUserModify(aMozUserModify); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserModify(const nsAString & aMozUserModify) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozUserModify(aMozUserModify); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozUserSelect(nsAString & aMozUserSelect) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozUserSelect(aMozUserSelect); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozUserSelect(const nsAString & aMozUserSelect) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozUserSelect(aMozUserSelect); } \
  NS_SCRIPTABLE NS_IMETHOD GetOpacity(nsAString & aOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOpacity(aOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD SetOpacity(const nsAString & aOpacity) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOpacity(aOpacity); } \
  NS_SCRIPTABLE NS_IMETHOD GetOutlineOffset(nsAString & aOutlineOffset) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOutlineOffset(aOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD SetOutlineOffset(const nsAString & aOutlineOffset) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOutlineOffset(aOutlineOffset); } \
  NS_SCRIPTABLE NS_IMETHOD GetOverflowX(nsAString & aOverflowX) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOverflowX(aOverflowX); } \
  NS_SCRIPTABLE NS_IMETHOD SetOverflowX(const nsAString & aOverflowX) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOverflowX(aOverflowX); } \
  NS_SCRIPTABLE NS_IMETHOD GetOverflowY(nsAString & aOverflowY) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOverflowY(aOverflowY); } \
  NS_SCRIPTABLE NS_IMETHOD SetOverflowY(const nsAString & aOverflowY) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetOverflowY(aOverflowY); } \
  NS_SCRIPTABLE NS_IMETHOD GetImeMode(nsAString & aImeMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetImeMode(aImeMode); } \
  NS_SCRIPTABLE NS_IMETHOD SetImeMode(const nsAString & aImeMode) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetImeMode(aImeMode); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEnd(nsAString & aMozBorderEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderEnd(aMozBorderEnd); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEnd(const nsAString & aMozBorderEnd) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderEnd(aMozBorderEnd); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndColor(nsAString & aMozBorderEndColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderEndColor(aMozBorderEndColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndColor(const nsAString & aMozBorderEndColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderEndColor(aMozBorderEndColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndStyle(nsAString & aMozBorderEndStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderEndStyle(aMozBorderEndStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndStyle(const nsAString & aMozBorderEndStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderEndStyle(aMozBorderEndStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderEndWidth(nsAString & aMozBorderEndWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderEndWidth(aMozBorderEndWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderEndWidth(const nsAString & aMozBorderEndWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderEndWidth(aMozBorderEndWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStart(nsAString & aMozBorderStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderStart(aMozBorderStart); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStart(const nsAString & aMozBorderStart) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderStart(aMozBorderStart); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartColor(nsAString & aMozBorderStartColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderStartColor(aMozBorderStartColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartColor(const nsAString & aMozBorderStartColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderStartColor(aMozBorderStartColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartStyle(nsAString & aMozBorderStartStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderStartStyle(aMozBorderStartStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartStyle(const nsAString & aMozBorderStartStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderStartStyle(aMozBorderStartStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderStartWidth(nsAString & aMozBorderStartWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderStartWidth(aMozBorderStartWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderStartWidth(const nsAString & aMozBorderStartWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderStartWidth(aMozBorderStartWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozStackSizing(nsAString & aMozStackSizing) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozStackSizing(aMozStackSizing); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozStackSizing(const nsAString & aMozStackSizing) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozStackSizing(aMozStackSizing); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBoxShadow(nsAString & aMozBoxShadow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBoxShadow(aMozBoxShadow); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBoxShadow(const nsAString & aMozBoxShadow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBoxShadow(aMozBoxShadow); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBorderImage(nsAString & aMozBorderImage) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBorderImage(aMozBorderImage); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBorderImage(const nsAString & aMozBorderImage) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBorderImage(aMozBorderImage); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRule(nsAString & aMozColumnRule) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozColumnRule(aMozColumnRule); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRule(const nsAString & aMozColumnRule) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozColumnRule(aMozColumnRule); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleWidth(nsAString & aMozColumnRuleWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozColumnRuleWidth(aMozColumnRuleWidth); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleWidth(const nsAString & aMozColumnRuleWidth) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozColumnRuleWidth(aMozColumnRuleWidth); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleStyle(nsAString & aMozColumnRuleStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozColumnRuleStyle(aMozColumnRuleStyle); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleStyle(const nsAString & aMozColumnRuleStyle) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozColumnRuleStyle(aMozColumnRuleStyle); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozColumnRuleColor(nsAString & aMozColumnRuleColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozColumnRuleColor(aMozColumnRuleColor); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozColumnRuleColor(const nsAString & aMozColumnRuleColor) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozColumnRuleColor(aMozColumnRuleColor); } \
  NS_SCRIPTABLE NS_IMETHOD GetWordWrap(nsAString & aWordWrap) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetWordWrap(aWordWrap); } \
  NS_SCRIPTABLE NS_IMETHOD SetWordWrap(const nsAString & aWordWrap) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetWordWrap(aWordWrap); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozTransform(nsAString & aMozTransform) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozTransform(aMozTransform); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozTransform(const nsAString & aMozTransform) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozTransform(aMozTransform); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozTransformOrigin(nsAString & aMozTransformOrigin) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozTransformOrigin(aMozTransformOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozTransformOrigin(const nsAString & aMozTransformOrigin) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozTransformOrigin(aMozTransformOrigin); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozWindowShadow(nsAString & aMozWindowShadow) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozWindowShadow(aMozWindowShadow); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozWindowShadow(const nsAString & aMozWindowShadow) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozWindowShadow(aMozWindowShadow); } \
  NS_SCRIPTABLE NS_IMETHOD GetMozBackgroundSize(nsAString & aMozBackgroundSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetMozBackgroundSize(aMozBackgroundSize); } \
  NS_SCRIPTABLE NS_IMETHOD SetMozBackgroundSize(const nsAString & aMozBackgroundSize) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetMozBackgroundSize(aMozBackgroundSize); } \
  NS_SCRIPTABLE NS_IMETHOD GetPointerEvents(nsAString & aPointerEvents) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPointerEvents(aPointerEvents); } \
  NS_SCRIPTABLE NS_IMETHOD SetPointerEvents(const nsAString & aPointerEvents) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetPointerEvents(aPointerEvents); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMNSCSS2Properties : public nsIDOMNSCSS2Properties
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMNSCSS2PROPERTIES

  nsDOMNSCSS2Properties();

private:
  ~nsDOMNSCSS2Properties();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMNSCSS2Properties, nsIDOMNSCSS2Properties)

nsDOMNSCSS2Properties::nsDOMNSCSS2Properties()
{
  /* member initializers and constructor code */
}

nsDOMNSCSS2Properties::~nsDOMNSCSS2Properties()
{
  /* destructor code */
}

/* attribute DOMString MozAppearance; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozAppearance(nsAString & aMozAppearance)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozAppearance(const nsAString & aMozAppearance)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBackgroundClip; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBackgroundClip(nsAString & aMozBackgroundClip)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBackgroundClip(const nsAString & aMozBackgroundClip)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBackgroundInlinePolicy; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBackgroundInlinePolicy(nsAString & aMozBackgroundInlinePolicy)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBackgroundInlinePolicy(const nsAString & aMozBackgroundInlinePolicy)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBackgroundOrigin; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBackgroundOrigin(nsAString & aMozBackgroundOrigin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBackgroundOrigin(const nsAString & aMozBackgroundOrigin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBinding; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBinding(nsAString & aMozBinding)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBinding(const nsAString & aMozBinding)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderBottomColors; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderBottomColors(nsAString & aMozBorderBottomColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderBottomColors(const nsAString & aMozBorderBottomColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderLeftColors; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderLeftColors(nsAString & aMozBorderLeftColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderLeftColors(const nsAString & aMozBorderLeftColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderRightColors; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderRightColors(nsAString & aMozBorderRightColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderRightColors(const nsAString & aMozBorderRightColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderTopColors; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderTopColors(nsAString & aMozBorderTopColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderTopColors(const nsAString & aMozBorderTopColors)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderRadius; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderRadius(nsAString & aMozBorderRadius)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderRadius(const nsAString & aMozBorderRadius)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderRadiusTopleft; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderRadiusTopleft(nsAString & aMozBorderRadiusTopleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderRadiusTopleft(const nsAString & aMozBorderRadiusTopleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderRadiusTopright; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderRadiusTopright(nsAString & aMozBorderRadiusTopright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderRadiusTopright(const nsAString & aMozBorderRadiusTopright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderRadiusBottomleft; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderRadiusBottomleft(nsAString & aMozBorderRadiusBottomleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderRadiusBottomleft(const nsAString & aMozBorderRadiusBottomleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderRadiusBottomright; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderRadiusBottomright(nsAString & aMozBorderRadiusBottomright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderRadiusBottomright(const nsAString & aMozBorderRadiusBottomright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxAlign; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxAlign(nsAString & aMozBoxAlign)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxAlign(const nsAString & aMozBoxAlign)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxDirection; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxDirection(nsAString & aMozBoxDirection)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxDirection(const nsAString & aMozBoxDirection)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxFlex; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxFlex(nsAString & aMozBoxFlex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxFlex(const nsAString & aMozBoxFlex)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxOrient; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxOrient(nsAString & aMozBoxOrient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxOrient(const nsAString & aMozBoxOrient)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxOrdinalGroup; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxOrdinalGroup(nsAString & aMozBoxOrdinalGroup)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxOrdinalGroup(const nsAString & aMozBoxOrdinalGroup)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxPack; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxPack(nsAString & aMozBoxPack)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxPack(const nsAString & aMozBoxPack)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxSizing; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxSizing(nsAString & aMozBoxSizing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxSizing(const nsAString & aMozBoxSizing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozColumnCount; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozColumnCount(nsAString & aMozColumnCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozColumnCount(const nsAString & aMozColumnCount)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozColumnWidth; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozColumnWidth(nsAString & aMozColumnWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozColumnWidth(const nsAString & aMozColumnWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozColumnGap; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozColumnGap(nsAString & aMozColumnGap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozColumnGap(const nsAString & aMozColumnGap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozFloatEdge; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozFloatEdge(nsAString & aMozFloatEdge)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozFloatEdge(const nsAString & aMozFloatEdge)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozForceBrokenImageIcon; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozForceBrokenImageIcon(nsAString & aMozForceBrokenImageIcon)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozForceBrokenImageIcon(const nsAString & aMozForceBrokenImageIcon)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozImageRegion; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozImageRegion(nsAString & aMozImageRegion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozImageRegion(const nsAString & aMozImageRegion)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozMarginEnd; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozMarginEnd(nsAString & aMozMarginEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozMarginEnd(const nsAString & aMozMarginEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozMarginStart; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozMarginStart(nsAString & aMozMarginStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozMarginStart(const nsAString & aMozMarginStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOpacity; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOpacity(nsAString & aMozOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOpacity(const nsAString & aMozOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutline; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutline(nsAString & aMozOutline)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutline(const nsAString & aMozOutline)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineColor; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineColor(nsAString & aMozOutlineColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineColor(const nsAString & aMozOutlineColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineRadius; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineRadius(nsAString & aMozOutlineRadius)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineRadius(const nsAString & aMozOutlineRadius)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineRadiusTopleft; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineRadiusTopleft(nsAString & aMozOutlineRadiusTopleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineRadiusTopleft(const nsAString & aMozOutlineRadiusTopleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineRadiusTopright; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineRadiusTopright(nsAString & aMozOutlineRadiusTopright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineRadiusTopright(const nsAString & aMozOutlineRadiusTopright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineRadiusBottomleft; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineRadiusBottomleft(nsAString & aMozOutlineRadiusBottomleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineRadiusBottomleft(const nsAString & aMozOutlineRadiusBottomleft)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineRadiusBottomright; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineRadiusBottomright(nsAString & aMozOutlineRadiusBottomright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineRadiusBottomright(const nsAString & aMozOutlineRadiusBottomright)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineStyle; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineStyle(nsAString & aMozOutlineStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineStyle(const nsAString & aMozOutlineStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineWidth; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineWidth(nsAString & aMozOutlineWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineWidth(const nsAString & aMozOutlineWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozOutlineOffset; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozOutlineOffset(nsAString & aMozOutlineOffset)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozOutlineOffset(const nsAString & aMozOutlineOffset)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozPaddingEnd; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozPaddingEnd(nsAString & aMozPaddingEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozPaddingEnd(const nsAString & aMozPaddingEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozPaddingStart; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozPaddingStart(nsAString & aMozPaddingStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozPaddingStart(const nsAString & aMozPaddingStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozUserFocus; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozUserFocus(nsAString & aMozUserFocus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozUserFocus(const nsAString & aMozUserFocus)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozUserInput; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozUserInput(nsAString & aMozUserInput)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozUserInput(const nsAString & aMozUserInput)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozUserModify; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozUserModify(nsAString & aMozUserModify)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozUserModify(const nsAString & aMozUserModify)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozUserSelect; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozUserSelect(nsAString & aMozUserSelect)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozUserSelect(const nsAString & aMozUserSelect)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString opacity; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetOpacity(nsAString & aOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetOpacity(const nsAString & aOpacity)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString outlineOffset; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetOutlineOffset(nsAString & aOutlineOffset)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetOutlineOffset(const nsAString & aOutlineOffset)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString overflowX; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetOverflowX(nsAString & aOverflowX)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetOverflowX(const nsAString & aOverflowX)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString overflowY; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetOverflowY(nsAString & aOverflowY)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetOverflowY(const nsAString & aOverflowY)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString imeMode; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetImeMode(nsAString & aImeMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetImeMode(const nsAString & aImeMode)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderEnd; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderEnd(nsAString & aMozBorderEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderEnd(const nsAString & aMozBorderEnd)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderEndColor; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderEndColor(nsAString & aMozBorderEndColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderEndColor(const nsAString & aMozBorderEndColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderEndStyle; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderEndStyle(nsAString & aMozBorderEndStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderEndStyle(const nsAString & aMozBorderEndStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderEndWidth; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderEndWidth(nsAString & aMozBorderEndWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderEndWidth(const nsAString & aMozBorderEndWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderStart; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderStart(nsAString & aMozBorderStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderStart(const nsAString & aMozBorderStart)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderStartColor; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderStartColor(nsAString & aMozBorderStartColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderStartColor(const nsAString & aMozBorderStartColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderStartStyle; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderStartStyle(nsAString & aMozBorderStartStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderStartStyle(const nsAString & aMozBorderStartStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderStartWidth; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderStartWidth(nsAString & aMozBorderStartWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderStartWidth(const nsAString & aMozBorderStartWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozStackSizing; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozStackSizing(nsAString & aMozStackSizing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozStackSizing(const nsAString & aMozStackSizing)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBoxShadow; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBoxShadow(nsAString & aMozBoxShadow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBoxShadow(const nsAString & aMozBoxShadow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBorderImage; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBorderImage(nsAString & aMozBorderImage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBorderImage(const nsAString & aMozBorderImage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozColumnRule; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozColumnRule(nsAString & aMozColumnRule)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozColumnRule(const nsAString & aMozColumnRule)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozColumnRuleWidth; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozColumnRuleWidth(nsAString & aMozColumnRuleWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozColumnRuleWidth(const nsAString & aMozColumnRuleWidth)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozColumnRuleStyle; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozColumnRuleStyle(nsAString & aMozColumnRuleStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozColumnRuleStyle(const nsAString & aMozColumnRuleStyle)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozColumnRuleColor; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozColumnRuleColor(nsAString & aMozColumnRuleColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozColumnRuleColor(const nsAString & aMozColumnRuleColor)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString wordWrap; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetWordWrap(nsAString & aWordWrap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetWordWrap(const nsAString & aWordWrap)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozTransform; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozTransform(nsAString & aMozTransform)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozTransform(const nsAString & aMozTransform)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozTransformOrigin; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozTransformOrigin(nsAString & aMozTransformOrigin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozTransformOrigin(const nsAString & aMozTransformOrigin)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozWindowShadow; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozWindowShadow(nsAString & aMozWindowShadow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozWindowShadow(const nsAString & aMozWindowShadow)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString MozBackgroundSize; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetMozBackgroundSize(nsAString & aMozBackgroundSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetMozBackgroundSize(const nsAString & aMozBackgroundSize)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute DOMString pointerEvents; */
NS_IMETHODIMP nsDOMNSCSS2Properties::GetPointerEvents(nsAString & aPointerEvents)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsDOMNSCSS2Properties::SetPointerEvents(const nsAString & aPointerEvents)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMNSCSS2Properties_h__ */
